==> haskell-irc-core-2.12-94.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-irc-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 irc-core
version:              2.12
visibility:           public
id:                   irc-core-2.12-IqXh2eW4tgqDZTWp657Kqr
key:                  irc-core-2.12-IqXh2eW4tgqDZTWp657Kqr
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc
    .
    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  7c3e56459dea2c3b578acb55e0deb17e
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.6.6/site-local/irc-core-2.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/irc-core-2.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/irc-core-2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.12-IqXh2eW4tgqDZTWp657Kqr
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr bytestring-0.11.5.3
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ text-2.0.2 time-1.12.2
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-irc-core-2.12-95-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-irc-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 irc-core
version:              2.12
visibility:           public
id:                   irc-core-2.12-6nBu5D7fDj6JFG37XMtzxC
key:                  irc-core-2.12-6nBu5D7fDj6JFG37XMtzxC
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc
    .
    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  5abde2440951670ee7476bda6e32d6c4
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.6.6/site-local/irc-core-2.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/irc-core-2.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/irc-core-2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.12-6nBu5D7fDj6JFG37XMtzxC
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi text-2.0.2 time-1.12.2
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
